/*
 * Copyright (c) 2022-present Charles7c Authors. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.zayac.admin.agent.model.resp;

import java.io.Serial;
import java.math.BigDecimal;

import lombok.Data;

import io.swagger.v3.oas.annotations.media.Schema;

import com.alibaba.excel.annotation.ExcelIgnoreUnannotated;
import com.alibaba.excel.annotation.ExcelProperty;

import top.continew.starter.extension.crud.model.resp.BaseDetailResp;

/**
 * 财务报汇总详情信息
 *
 * @author zayac
 * @since 2024/06/04 17:10
 */
@Data
@ExcelIgnoreUnannotated
@Schema(description = "财务报汇总详情信息")
public class FinanceSumDetailResp extends BaseDetailResp {

    @Serial
    private static final long serialVersionUID = 1L;

    /**
     * 下属用户数量总和
     */
    @Schema(description = "下属用户数量总和")
    @ExcelProperty(value = "下属用户数量总和")
    private Integer subordinateUserCountSum;

    /**
     * 活跃总和
     */
    @Schema(description = "活跃总和")
    @ExcelProperty(value = "活跃总和")
    private Integer activeSum;

    /**
     * 净利润总和
     */
    @Schema(description = "净利润总和")
    @ExcelProperty(value = "净利润总和")
    private BigDecimal netProfitSum;

    /**
     * 上一次余额总和
     */
    @Schema(description = "上一次余额总和")
    @ExcelProperty(value = "上一次余额总和")
    private BigDecimal lastBalanceSum;

    /**
     * 调整后利润总和
     */
    @Schema(description = "调整后利润总和")
    @ExcelProperty(value = "调整后利润总和")
    private BigDecimal czProfitSum;

    /**
     * 费率
     */
    @Schema(description = "费率")
    @ExcelProperty(value = "费率")
    private BigDecimal rate;

    /**
     * 修正总和
     */
    @Schema(description = "修正总和")
    @ExcelProperty(value = "修正总和")
    private BigDecimal correctionSum;

    /**
     * 重复修正总和
     */
    @Schema(description = "重复修正总和")
    @ExcelProperty(value = "重复修正总和")
    private BigDecimal repCorrectionSum;

    /**
     * 佣金总和
     */
    @Schema(description = "佣金总和")
    @ExcelProperty(value = "佣金总和")
    private BigDecimal commissionSum;

    /**
     * VIP特殊佣金总和
     */
    @Schema(description = "VIP特殊佣金总和")
    @ExcelProperty(value = "VIP特殊佣金总和")
    private BigDecimal vipSpecialCommissionSum;

    /**
     * 修正后的净利润
     */
    @Schema(description = "修正后的净利润")
    @ExcelProperty(value = "修正后的净利润")
    private BigDecimal repairNetProfit;

    /**
     * 佣金状态
     */
    @Schema(description = "佣金状态")
    @ExcelProperty(value = "佣金状态")
    private Integer commissionStatus;

    /**
     * 代理名称
     */
    @Schema(description = "代理名称")
    @ExcelProperty(value = "代理名称")
    private String agentName;

    /**
     * 有效新用户总和
     */
    @Schema(description = "有效新用户总和")
    @ExcelProperty(value = "有效新用户总和")
    private Integer effectiveNewSum;

    /**
     * 手续费
     */
    @Schema(description = "手续费")
    @ExcelProperty(value = "手续费")
    private BigDecimal handlingFee;

    /**
     * 合作利润
     */
    @Schema(description = "合作利润")
    @ExcelProperty(value = "合作利润")
    private Integer partnershipProfit;

    /**
     * 彩票投注总和
     */
    @Schema(description = "彩票投注总和")
    @ExcelProperty(value = "彩票投注总和")
    private Integer lotteryBetSum;

    /**
     * 回扣率总和
     */
    @Schema(description = "回扣率总和")
    @ExcelProperty(value = "回扣率总和")
    private BigDecimal rebateRateSum;

    /**
     * 彩票佣金总和
     */
    @Schema(description = "彩票佣金总和")
    @ExcelProperty(value = "彩票佣金总和")
    private BigDecimal lotteryCommissionSum;

    /**
     * 负利润佣金总和
     */
    @Schema(description = "负利润佣金总和")
    @ExcelProperty(value = "负利润佣金总和")
    private BigDecimal negativeProfitCommissionSum;

    /**
     * 负利润率总和
     */
    @Schema(description = "负利润率总和")
    @ExcelProperty(value = "负利润率总和")
    private BigDecimal negativeProfitRateSum;

    /**
     * 成本率总和
     */
    @Schema(description = "成本率总和")
    @ExcelProperty(value = "成本率总和")
    private BigDecimal costRateSum;

    /**
     * 成本金额总和
     */
    @Schema(description = "成本金额总和")
    @ExcelProperty(value = "成本金额总和")
    private BigDecimal costMoneySum;

    /**
     * 利润总和
     */
    @Schema(description = "利润总和")
    @ExcelProperty(value = "利润总和")
    private BigDecimal profitSum;

    /**
     * 第三方支出总和
     */
    @Schema(description = "第三方支出总和")
    @ExcelProperty(value = "第三方支出总和")
    private BigDecimal thirdPartySpendSum;

    /**
     * 促销总和
     */
    @Schema(description = "促销总和")
    @ExcelProperty(value = "促销总和")
    private BigDecimal promoSum;

    /**
     * 回扣总和
     */
    @Schema(description = "回扣总和")
    @ExcelProperty(value = "回扣总和")
    private BigDecimal rebateSum;

    /**
     * 风险调整总和
     */
    @Schema(description = "风险调整总和")
    @ExcelProperty(value = "风险调整总和")
    private BigDecimal riskAdjustSum;
}