/*
 * Copyright (c) 2022-present Charles7c Authors. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.zayac.admin.system.model.query;

import java.io.Serial;
import java.io.Serializable;

import lombok.Data;

import io.swagger.v3.oas.annotations.media.Schema;

import top.continew.starter.data.core.annotation.Query;
import top.continew.starter.data.core.enums.QueryType;

/**
 * 平台查询条件
 *
 * @author zayac
 * @since 2024/05/14 12:28
 */
@Data
@Schema(description = "平台查询条件")
public class PlatformQuery implements Serializable {

    @Serial
    private static final long serialVersionUID = 1L;

    /**
     * 平台ID
     */
    @Schema(description = "平台代码", example = "1")
    @Query(type = QueryType.EQ)
    private Integer code;

    /**
     * 平台名称
     */
    @Schema(description = "平台名称", example = "开云")
    @Query(type = QueryType.LIKE)
    private String name;

    /**
     * 平台别称
     */
    @Schema(description = "平台别称", example = "ky")
    @Query(type = QueryType.LIKE)
    private String nickname;

    /**
     * 平台地址
     */
    @Schema(description = "平台地址", example = "https://www.nvdf9.com:8003")
    @Query(type = QueryType.EQ)
    private String url;

    /**
     * 状态(1启用,2禁用)
     */
    @Schema(description = "状态(1启用,2禁用)", example = "1")
    @Query(type = QueryType.EQ)
    private Integer status;
}